@@ -202,7 +202,7 @@ def amazon_to_html( item, with_image = true, label = nil, pos = 'amazon' )
 		unless image[:src] then
 			img = ''
 		else
-			size = @conf.iphone? ? '' : %Q|height="#{h image[:height]}" width="#{h image[:width]}"|
+			size = @cgi.smartphone? ? '' : %Q|height="#{h image[:height]}" width="#{h image[:width]}"|
 			img = <<-HTML
 			<img class="#{h pos}" src="#{h image[:src]}"
 			#{size} alt="#{h alt}">
