@@ -1,5 +1,5 @@
 =begin
-= Search control plugin((-$Id: search_control.rb,v 1.2 2004/11/09 21:07:45 zunda Exp $-))
+= Search control plugin((-$Id: search_control.rb,v 1.2 2004-11-09 21:07:45 zunda Exp $-))
 English resource
 
 == Summary
@@ -65,3 +65,10 @@ _HTML
 		[ 'Category', 'category' ]
 	]
 end
+
+# Local Variables:
+# mode: ruby
+# indent-tabs-mode: t
+# tab-width: 3
+# ruby-indent-level: 3
+# End:
