@@ -1,16 +1,17 @@
-# gradation.rb $Revision: 1.3 $
+# -*- coding: utf-8 -*-
+# gradation.rb
 #
-# gradation.rb: ʸ򥰥ǡɽ
-#   ѥ᥿:
-#     str:         ʸ
-#     first_color: ǡ󳫻Ͽ(16 6)
-#     last_color:  ǡλ(16 6)
+# gradation.rb: 文字列をグラデーション表示
+#   パラメタ:
+#     str:         文字列
+#     first_color: グラデーション開始色(16進 6桁指定)
+#     last_color:  グラデーション終了色(16進 6桁指定)
 #
 # Copyright (c) 2002 TADA Tadashi <sho@spc.gr.jp>
 # You can distribute this file under the GPL2.
 #
 def gradation( str, first_color, last_color )
-	ary = str.split( // )
+	ary = str.split( //u )
 	len = ary.length - 1
 	result = ""
 	r = first_color[0..1].hex.to_f
@@ -29,3 +30,10 @@ def gradation( str, first_color, last_color )
 	result
 end
 
+
+# Local Variables:
+# mode: ruby
+# indent-tabs-mode: t
+# tab-width: 3
+# ruby-indent-level: 3
+# End:
