@@ -1,19 +1,20 @@
-# gradient.rb $Revision: 1.3 $
+# -*- coding: utf-8 -*-
+# gradient.rb
 #
-# gradient.rb: ʸ礭Ѳʤɽ
-#   ѥ᥿:
-#     str:        ʸ
-#     first_size: ʸ(͡ñpt)
-#     last_size:  ʸ(͡ñpt)
+# gradient.rb: 文字の大きさを変化させながら表示
+#   パラメタ:
+#     str:        文字列
+#     first_size: 開始文字サイズ(数値、単位pt)
+#     last_size:  開始文字サイズ(数値、単位pt)
 #
-#   : ֤ʤȤǤޤפ10pt30pt˳
-#     <%=gradient 'ʤȤǤޤ', 10, 30 %>
+#   例: 「こんなこともできます」を10ptから30ptに拡大
+#     <%=gradient 'こんなこともできます', 10, 30 %>
 #
 # Copyright (c) 2002 TADA Tadashi <sho@spc.gr.jp>
 # You can distribute this file under the GPL2.
 #
 def gradient( str, first_size, last_size )
-	ary = str.split( // )
+	ary = str.split( //u )
 	len = ary.length - 1
 	result = ""
 	fontsize = first_size.to_f
@@ -26,3 +27,10 @@ def gradient( str, first_size, last_size )
 	result
 end
 
+
+# Local Variables:
+# mode: ruby
+# indent-tabs-mode: t
+# tab-width: 3
+# ruby-indent-level: 3
+# End:
