@@ -64,7 +64,7 @@
 @amazon_item_image = %r|(<img src="(http://images-jp\.amazon\.com/images/P/(.*MZZZZZZZ_?.jpg))".*?>)|i
 @amazon_label_conf ='Amazon'
 @amazon_label_aid = 'AmazonアソシエイトIDの指定'
-@amazon_label_aid_desc = '指定しない場合には、tDiary作者の所有するIDが指定されたことになりますのでご注意ください。'
+@amazon_label_aid_desc = '日本のAmazonが扱う商品にのみ適用されます。他の国のアソシエイトIDを利用する場合はtdiary.confで指定して下さい。なお指定しない場合には、Amazon認証Proxyサービスの指定するIDが使われますのでご注意下さい。'
 @amazon_label_imgsize = '表示するイメージのサイズ'
 @amazon_label_large = '大きい'
 @amazon_label_regular = '普通'
@@ -72,6 +72,9 @@
 @amazon_label_title = 'isbn_imageプラグインで商品名を'
 @amazon_label_hide = '表示しない'
 @amazon_label_show = '表示する'
+@amazon_label_bitly = 'bit.lyを使って商品のURLを'
+@amazon_label_bitly_enabled = '短縮する'
+@amazon_label_bitly_disabled = '短縮しない'
 @amazon_label_notfound = 'イメージが見つからないときは'
 @amazon_label_usetitle = '商品名を表示する'
 @amazon_label_usedefault = 'デフォルトのイメージを使う'
