@@ -1,44 +1,45 @@
+# -*- coding: utf-8 -*-
 =begin
-= Meta-scheme plugin((-$Id: referer_scheme.rb,v 1.8 2004/07/30 18:38:33 zunda Exp $-))
-Υ󥯸ִꥹȤεҤڤˤޤ
+= Meta-scheme plugin((-$Id: referer_scheme.rb,v 1.9 2008-03-02 09:01:46 kazuhiko Exp $-))
+本日のリンク元置換リストの記述を楽にします。
 
-== ˡ
-Υץ饰򡢥ץ饰Υǥ쥯ȥ뤫ץ饰ץ饰
-󤫤ͭˤƤ
+== 利用方法
+このプラグインを、プラグインのディレクトリに入れるかプラグイン選択プラグ
+インから有効にしてください。
 
-ˡꡢ󥯸顢󥯸ִꥹȤԽơtdiary:
-hatena:Ȥץեå(᥿ȸƤ֤Ȥˤޤ)URL
-դƤ
+次に、設定、リンク元から、リンク元置換リストを編集して、tdiary:や
+hatena:というプレフィックス(メタ・スキームと呼ぶことにします)をURLの前に
+付けてください。
 
-ˤꡢդִ롼񤫤ʤǤ⡢ִʸ˼ưŪ
-դʤɤ뤳ȤǤޤ
+これにより、日付を置換するルールを書かないでも、置換後の文字列に自動的に
+日付などを挿入することができます。
 
-㤨СΤ褦ʵҤ򤷤Ƥ
-* tdiary:http://tdiary.tdiary.net/ tDiary.net
-* tdiarynet:foo((-http://foo.tdiary.net/Ÿޤ-)) foo
-* hatena:bar((-http://d.hatena.ne.jp/bar/Ÿޤ-)) bar
-ǤϡURLդޤޤС(YYYY-MM-DD)Ȥɲäޤ
+例えば、次のような記述をしてください。
+* tdiary:http://tdiary.tdiary.net/ tDiary.net運営日誌
+* tdiarynet:foo((-http://foo.tdiary.net/に展開されます-)) fooさんの日記
+* hatena:bar((-http://d.hatena.ne.jp/bar/に展開されます-)) barさんの日記
+この例では、URLに日付が含まれれば、(YYYY-MM-DD)という形式で追加します。
 
-== 
-tdiary:ǻϤޤURLϡ
-* ̤ȤʤǤ
-* /ǽ餻Ƥ
+== 注意
+tdiary:で始まるURLは、
+* 括弧を使わないでください。
+* /で終わらせてください。
 
-tdiarynet:hatena:ǻϤޤURLϡ
-* ̤ȤʤǤ
-* URLȤƤϥ桼IDꤷƤ
+tdiarynet:やhatena:で始まるURLは、
+* 括弧を使わないでください。
+* URLとしてはユーザーIDだけを指定してください。
 
-== ᥿κ
-󥯸ִꥹȤURLɽʸФơ/^(\w+):/Ȥɽ
-ǰפʸ󤬥᥿ȤƸФޤ
-  def scheme_̾( url, name )
+== メタ・スキームの作り方
+リンク元置換リストのURLの正規表現の文字列に対して、/^(\w+):/という正規表
+現で一致する文字列がメタ・スキームとして検出されます。
+  def scheme_スキーム名( url, name )
     :
     yield( url_variants, name_variants )
     :
   end
-Ȥ@conf.referer_tableðۥ᥽åɤ򥤥ƥ졼ȤƤС
-ִꥹȤεҤ˱ƤΥ᥽åɤƤФޤurlˤ
-֥᥿̾:פɽϤ뤳ȤդƤ
+という@conf.referer_tableの特異メソッドをイテレータとして定義しておけば、
+置換リストの記述に応じてこのメソッドが呼ばれます。urlには
+「メタ・スキーム名:」を除いた正規表現が渡されることに注意してください。
 
 == Copyright
 Copyright (C) 2003 zunda <zunda at freeshell.org>
@@ -76,3 +77,10 @@ unless @conf.referer_table.respond_to?( 'scheme_hatena', true ) then
 		end
 	end
 end
+
+# Local Variables:
+# mode: ruby
+# indent-tabs-mode: t
+# tab-width: 3
+# ruby-indent-level: 3
+# End:
