@@ -30,11 +30,13 @@
 # You can distribute this under GPL.
 #
 
-require "nkf"
+unless String.method_defined?(:encode)
+	require 'nkf'
+end
 
 def kw_parse( str )
 	kw_list = []
-	str.each do |pair|
+	str.each_line do |pair|
 		k, u, s = pair.sub( /[\r\n]+/, '' ).split( /[ \t]+/, 3 )
 		k = nil if k == '' or k == 'nil'
 		s = nil if s != 'euc-jp' && s != 'sjis' && s != 'jis' && s != 'utf-8'
@@ -44,12 +46,7 @@ def kw_parse( str )
 end
 
 def kw_generate_dic
-	case @lang
-	when 'en'
-		kw_dic = {nil => ['http://www.google.com/search?q=$1', nil]}
-	else
-		kw_dic = {nil => ['http://www.google.com/search?ie=euc-jp&q=$1', 'euc-jp']}
-	end
+	kw_dic = {nil => ['http://www.google.com/search?ie=utf-8&q=$1', 'utf-8']}
 
 	kw_list = []
 	case @conf['kw.dic'].class.to_s
@@ -76,11 +73,19 @@ def kw( keyword, name = nil, title = nil )
 	keyword = key unless show_inter
 	name = keyword unless name
 	title = title ? %Q[ title="#{h title}"] : ''
-	begin
-		key = u( case @kw_dic[inter][1]
+
+	unless @kw_dic.has_key?(inter)
+		inter = nil
+	end
+	style = @kw_dic[inter][1]
+	if String.method_defined?(:encode)
+		if style
+			key = key.encode({'jis'=>'ISO-2022-JP', 'sjis'=>'Shift_JIS'}[style] || style)
+		end
+	else
+		key = case style
 			when 'euc-jp'
 				NKF::nkf( '-m0 -W -e', key )
-				key
 			when 'sjis'
 				NKF::nkf( '-m0 -W -s', key )
 			when 'jis'
@@ -89,12 +94,9 @@ def kw( keyword, name = nil, title = nil )
 				key
 			else # none
 				key
-		end )
-	rescue NameError
-		inter = nil
-		retry
+		end
 	end
-	%Q[<a href="#{h @kw_dic[inter][0].sub( /\$1/, key )}"#{title}>#{h name}</a>]
+	%Q[<a href="#{h @kw_dic[inter][0].sub( /\$1/, u( key ))}"#{title}>#{h name}</a>]
 end
 
 #
@@ -110,7 +112,7 @@ unless @resource_loaded then
 		<h3>リンクリストの指定</h3>
 		<p>特定のサイトへのリンクを、簡単な記述で生成するためのプラグイン(kw)です。
 		「キー URL エンコードスタイル」と空白で区切って指定します。例えば、</p>
-		<pre>google http://www.google.com/search?ie=euc-jp&amp;q=$1 euc-jp</pre>
+		<pre>google http://www.google.com/search?ie=utf-8&amp;q=$1 utf-8</pre>
 		<p>と指定すると、</p>
 		<pre>&lt;%=kw('google:tdiary')%&gt;</pre>
 		<p>のように日記に書けばgoogleでtdiaryを検索するリンクになります
@@ -140,7 +142,6 @@ add_conf_proc( 'kw', kw_label ) do
 	HTML
 end
 
-
 # Local Variables:
 # mode: ruby
 # indent-tabs-mode: t
