@@ -61,9 +61,10 @@ end
 
 class MakeRssFull
 	include ERB::Util
+	include TDiary::ViewHelper
 
-	def initialize( conf )
-		@conf = conf
+	def initialize(conf, cgi = CGI.new)
+		@conf, @cgi = conf, cgi
 		@item_num = 0
 	end
 
@@ -104,7 +105,7 @@ class MakeRssFull
 	def file
 		f = @conf['makerss.file'] || 'index.rdf'
 		f = 'index.rdf' if f.empty?
-		f
+		f =~ %r|^/| ? f : "#{TDiary.document_root}/#{f}"
 	end
 
 	def writable?
@@ -132,13 +133,13 @@ class MakeRssFull
 	end
 
 	def url
-		u = @conf['makerss.url'] || "#{@conf.base_url}#{File.basename(file)}"
-		u = "#{@conf.base_url}#{File.basename(file)}" if u.empty?
+		u = @conf['makerss.url'] || "#{base_url}#{File.basename(file)}"
+		u = "#{base_url}#{File.basename(file)}" if u.empty?
 		u
 	end
 end
 
-@makerss_rsses << MakeRssFull::new( @conf )
+@makerss_rsses << MakeRssFull::new(@conf, @cgi)
 
 class MakeRssNoComments < MakeRssFull
 	def title
@@ -153,7 +154,7 @@ class MakeRssNoComments < MakeRssFull
 	def file
 		f = @conf['makerss.no_comments.file'] || 'no_comments.rdf'
 		f = 'no_comments.rdf' if f.empty?
-		f
+		f =~ %r|^/| ? f : "#{TDiary.document_root}/#{f}"
 	end
 
 	def write( encoder )
@@ -163,20 +164,20 @@ class MakeRssNoComments < MakeRssFull
 
 	def url
 		return nil unless @conf['makerss.no_comments']
-		u = @conf['makerss.no_comments.url'] || "#{@conf.base_url}#{File.basename(file)}"
-		u = "#{@conf.base_url}#{File.basename(file)}" if u.empty?
+		u = @conf['makerss.no_comments.url'] || "#{base_url}#{File.basename(file)}"
+		u = "#{base_url}#{File.basename(file)}" if u.empty?
 		u
 	end
 end
 
-@makerss_rsses << MakeRssNoComments::new( @conf )
+@makerss_rsses << MakeRssNoComments::new(@conf, @cgi)
 
 def makerss_update
 	date = @date.strftime( "%Y%m%d" )
 	diary = @diaries[date]
 
 	uri = @conf.index.dup
-	uri[0, 0] = @conf.base_url if %r|^https?://|i !~ @conf.index
+	uri[0, 0] = base_url if %r|^https?://|i !~ @conf.index
 	uri.gsub!( %r|/\./|, '/' )
 
 	require 'pstore'
@@ -256,7 +257,7 @@ def makerss_update
 		if /^http/ =~ @conf.banner
 			rdf_image = @conf.banner
 		else
-			rdf_image = @conf.base_url + @conf.banner
+			rdf_image = base_url + @conf.banner
 		end
 		rsses.each {|r| r.image( %Q[<image rdf:resource="#{h rdf_image}" />\n] ) }
 	end
@@ -269,8 +270,8 @@ def makerss_update
 end
 
 def makerss_header( uri )
-	rdf_url = @conf['makerss.url'] || "#{@conf.base_url}index.rdf"
-	rdf_url = "#{@conf.base_url}index.rdf" if rdf_url.empty?
+	rdf_url = @conf['makerss.url'] || "#{base_url}index.rdf"
+	rdf_url = "#{base_url}index.rdf" if rdf_url.empty?
 
 	desc = @conf.description || ''
 
@@ -362,7 +363,7 @@ def makerss_body( uri, rdfsec )
 			text << body_leave
 			unless text.empty?
 				uri = @conf.index.dup
-				uri[0, 0] = @conf.base_url unless %r|^https?://|i =~ uri
+				uri[0, 0] = base_url unless %r|^https?://|i =~ uri
 				uri.gsub!( %r|/\./|, '/' )
 				text = absolutify( text, uri )
 				text.gsub!( /\]\]>/, ']]]]><![CDATA[>' )
@@ -719,7 +720,7 @@ def absolutify(html, baseurl)
 					uri = URI.parse(location)
 					if uri.relative?
 						location = (baseuri + location).to_s
-					elsif not uri.host
+					elsif not uri.host and uri.path
 						path = uri.path
 						path += '?' + uri.query if uri.query
 						path += '#' + uri.fragment if uri.fragment
