@@ -1,5 +1,5 @@
 =begin
-= Meta-scheme plugin((-$Id: referer_scheme.rb,v 1.9 2005/07/23 08:07:52 zunda Exp $-))
+= Meta-scheme plugin((-$Id: referer_scheme.rb,v 1.9 2005-07-23 08:07:52 zunda Exp $-))
 Enables to prefix `meta' schemes to URL regexp of the refer_table. See
 #{lang}/referer_scheme.rb for a documentation.
 
@@ -78,3 +78,10 @@ unless @conf.referer_table.respond_to?( 'referer_scheme_each_orig' ) then
 	end
 
 end
+
+# Local Variables:
+# mode: ruby
+# indent-tabs-mode: t
+# tab-width: 3
+# ruby-indent-level: 3
+# End:
