@@ -1,5 +1,6 @@
+# -*- coding: utf-8 -*-
 =begin
-= ץ饰/search control plugin((-$Id: search_control.rb,v 1.10 2007/05/03 02:36:03 tadatadashi Exp $-))
+= ここだけ検索プラグイン/search control plugin((-$Id: search_control.rb,v 1.11 2008-03-02 09:01:45 kazuhiko Exp $-))
 
 Under revision! TODO: add/remove user agents
 
@@ -217,3 +218,10 @@ add_header_proc do
 		''
 	end
 end
+
+# Local Variables:
+# mode: ruby
+# indent-tabs-mode: t
+# tab-width: 3
+# ruby-indent-level: 3
+# End:
