@@ -28,7 +28,7 @@
 #
  
 # running on only non mobile mode
-unless @conf.mobile_agent? then
+unless @cgi.mobile_agent? then
 
 #
 # show TrackBack ping URL
@@ -37,9 +37,9 @@ add_body_enter_proc do |date|
 	cgi = File.basename(@options['tb.cgi'] || './tb.rb')
 	@tb_date = date
 	@tb_id_url = %Q|#{@index}#{anchor( @tb_date.strftime('%Y%m%d') )}|
-	@tb_id_url[0, 0] = @conf.base_url if %r|^https?://|i !~ @conf.index
+	@tb_id_url[0, 0] = base_url if %r|^https?://|i !~ @conf.index
 	@tb_id_url.gsub!( %r|/\./|, '/' )
-	@tb_url = %Q|#{@conf.base_url}#{cgi}/#{@tb_date.strftime('%Y%m%d')}|
+	@tb_url = %Q|#{base_url}#{cgi}/#{@tb_date.strftime('%Y%m%d')}|
 	''
 end
 
