@@ -1,11 +1,12 @@
+# -*- coding: utf-8; -*-
 #
-# theme_convert.rb: tDiary 1.4 ѥơޤ 2.0 Ѥ*Ƥȡ*Ѵ
+# theme_convert.rb: tDiary 1.4 系用テーマを 2.0 系用に*てきとー*に変換する
 #
-# Ȥ: $ ruby theme_convert.rb hoge.css
-#         ȼ¹Ԥȡhoge-2.css  hoge-simple.css ޤ
-#         hoge-2.css  2.0 ѤѴ줿 CSS եǤ
-#         ٤Ϥ CSS եǽƤ
-#         hoge-simple.css ϺѤΰե
+# 使い方: $ ruby theme_convert.rb hoge.css
+#         と実行すると、hoge-2.css と hoge-simple.css が作成されます。
+#         hoge-2.css が 2.0 系用に変換された CSS ファイルです。
+#         細かい点はその CSS ファイルを手で修正してください。
+#         （hoge-simple.css は作業用の一時ファイル）
 #
 # Copyright (c) 2002 NT <nt@24i.net>
 # Distributed under the GPL
@@ -388,14 +389,14 @@ def theme_convert ( fname, hash )
             elsif %r[^#{x[0]}] =~ line
               f.puts x[1] + $'
               break
-            elsif %r[span\.commentator] =~ line # span.commentator ä
+            elsif %r[span\.commentator] =~ line #元々ある span.commentator を消す
               flag = true
             elsif i == table.size - 1 && %r[^#{x[0]}] !~ line
               f.puts line
             end
           }
         else
-          if flag && /\}/ =~ line # span.commentator ä³
+          if flag && /\}/ =~ line #元々ある span.commentator を消す（続き）
             flag = false
           elsif flag
           else
@@ -443,3 +444,10 @@ while cssname = ARGV.shift
   puts %Q[Conversion completed: #{cssname.sub( /\.css/i, "-2.css" )} was generated.]
 
 end
+
+# Local Variables:
+# mode: ruby
+# indent-tabs-mode: t
+# tab-width: 3
+# ruby-indent-level: 3
+# End:
