@@ -29,30 +29,14 @@ def spamfilter_conf_html
 			<option value="true"#{" selected" if @conf['spamfilter.bad_uri_patts_for_mails']}>利用する</option>
 			<option value="false"#{" selected" unless @conf['spamfilter.bad_uri_patts_for_mails']}>利用しない</option>
 		</select></p>
-	<p>TrackBack送信元の<select name="spamfilter.linkcheck">
-		<option value="0"#{' selected' if @conf['spamfilter.linkcheck'] == 0}>内容をチェックせずにすべて受信する</option>
-		<option value="1"#{' selected' if @conf['spamfilter.linkcheck'] == 1}>中に自サイトへのリンクがあれば受信する</option>
-	</select></p>
 
 	<h3>日付けによるフィルタ</h3>
 	<p><input type="text" name="spamfilter.date_limit" value="#{h @conf['spamfilter.date_limit']}" size="5">日以上前の日付けのツッコミフォームはjavascriptで表示する。<br>(空欄は制限なし、0は当日のみ)</p>
 
 	<h3>IPアドレスによるフィルタ</h3>
-	<p>ツッコミやTrackBack送信元のIPアドレスが、以下のパターンに当てはまる場合はspamとみなす(リストには完全なIPアドレスまたは「.」で終わるIPアドレスの一部を記述する)<br>
+	<p>ツッコミのIPアドレスが、以下のパターンに当てはまる場合はspamとみなす(リストには完全なIPアドレスまたは「.」で終わるIPアドレスの一部を記述する)<br>
 		<textarea name="spamfilter.bad_ip_addrs" cols="70" rows="5">#{h( @conf['spamfilter.bad_ip_addrs'] || '' )}</textarea></p>
 	</p>
-	<p>TrackBack送信元と実際のサイトのIPアドレスが異なる場合は
-		<select name="spamfilter.resolv_check">
-			<option value="true"#{" selected" if @conf['spamfilter.resolv_check']}>spamとみなす</option>
-			<option value="false"#{" selected" unless @conf['spamfilter.resolv_check']}>spamとみなさない</option>
-		</select>
-	</p>
-	<p>上の条件によってspamとみなされたTrackBackは
-		<select name="spamfilter.resolv_check_mode">
-			<option value="true"#{" selected" if @conf['spamfilter.resolv_check_mode']}>非表示にする</option>
-			<option value="false"#{" selected" unless @conf['spamfilter.resolv_check_mode']}>捨てる</option>
-		</select>
-	</p>
 	<h3>ツッコミの注意文</h3>
 	<p>ツッコミフォームの上に表示する注意文を設定します。spam判定条件を変更した場合に、読者にそれをきちんと知らせましょう<br>
 	<textarea name="comment_description" cols="70" rows="5">#{h comment_description}</textarea></p>
