@@ -3,11 +3,12 @@ require 'acceptance_helper'
 
 feature 'プラグイン選択設定の利用' do
 	plugin_path = "#{TDiary::PATH}/misc/plugin/rspec.rb"
+
 	scenario '新入荷のプラグインが表示される' do
 		FileUtils.rm plugin_path if File.exists? plugin_path
 
 		visit '/update.rb?conf=sp'
-		click_button 'OK'
+		page.all('div.saveconf').first.click_button 'OK'
 		page.should_not have_content '新入荷'
 
 		FileUtils.touch plugin_path
@@ -26,7 +27,7 @@ feature 'プラグイン選択設定の利用' do
 		visit '/update.rb?conf=sp'
 
 		check "sp.rspec.rb"
-		click_button 'OK'
+		page.all('div.saveconf').first.click_button 'OK'
 
 		page.should have_checked_field "sp.rspec.rb"
 
@@ -44,8 +45,23 @@ feature 'プラグイン選択設定の利用' do
 		click_link 'プラグイン選択'
 		page.should_not have_content 'rspec.rb'
 	end
-end
 
+	if RUBY_VERSION > '1.9'
+		scenario '外部の Javascript を追加するプラグインを有効にする' do
+			visit '/update.rb?conf=sp'
+
+			check "sp.category_autocomplete.rb"
+			page.all('div.saveconf').first.click_button 'OK'
+
+			visit '/update.rb'
+
+			page.body.should be_include('caretposition.js')
+			page.body.should be_include('category_autocomplete.js')
+			page.body.should be_include('http://ajax.googleapis.com/ajax/libs/jqueryui/1.8/jquery-ui.min.js')
+			page.body.should_not be_include('http://ajax.googleapis.com/ajax/libs/jqueryui/1.8/jquery-ui.min.js?')
+		end
+	end
+end
 # Local Variables:
 # mode: ruby
 # indent-tabs-mode: t
