@@ -1,5 +1,10 @@
 # coding: utf-8
 
+require 'capistrano_colors'
+
+require 'rvm/capistrano'
+set :rvm_type, :system
+
 require 'pit'
 config = Pit.get('tdiary', :require => {
     :username => 'your username',
@@ -17,8 +22,6 @@ server config[:server], :app
 
 set :user, config[:username]
 set :deploy_to, defer { "/home/#{user}/app/#{application}" }
-set :password, defer { Capistrano::CLI.password_prompt('sudo password: ') }
-set :use_sudo, true
 
 namespace :deploy do
   task :start do ; end
