@@ -17,8 +17,6 @@ module TDiary
 				@filter_mode = true
 				@max_uris = nil
 				@max_rate = nil
-				@resolv_check = true
-				@resolv_check_mode = true
 				@bad_uri_patts_for_mails = false
 
 				@bad_uri_patts = nil
@@ -58,12 +56,6 @@ module TDiary
 					@max_rate = nil
 				end
 
-				if @conf.options.include?('spamfilter.resolv_check')
-					@resolv_check = @conf.options['spamfilter.resolv_check']
-				else
-					@resolv_check = true
-				end
-
 				if @conf.options.include?('spamlookup.ip.list')
 					@spamlookup_ip_list = @conf.options['spamlookup.ip.list']
 				else
@@ -82,16 +74,6 @@ module TDiary
 					@spamlookup_safe_domain_list = "www.google.com\nwww.google.co.jp\nsearch.yahoo.co.jp\nwww.bing.com"
 				end
 
-				if @conf.options.include?('spamfilter.resolv_check_mode')
-					if @conf.options['spamfilter.resolv_check_mode']
-						@resolv_check_mode = true # invisible
-					else
-						@resolv_check_mode = false # drop
-					end
-				else
-					@resolv_check_mode = true # invisible
-				end
-
 				if @conf.options.include?('spamfilter.bad_uri_patts_for_mails')
 					@bad_uri_patts_for_mails =
 							@conf.options['spamfilter.bad_uri_patts_for_mails']
@@ -170,39 +152,30 @@ module TDiary
 				nil
 			end
 
-			def black_domain?( domain )
-				@spamlookup_ip_list.split(/[\n\r]+/).each do |dnsbl|
-					begin
-						timeout(5) do
-							ip = IPSocket::getaddress( domain ).split(/\./).reverse.join(".")
-							address = Resolv.getaddress( "#{ip}.#{dnsbl}" )
-							debug("lookup:#{ip}.#{dnsbl} address:#{address}")
-							return true
-						end
-					rescue Resolv::ResolvTimeout, Resolv::ResolvError
-					rescue TimeoutError
-						debug("timeout error:#{domain}.#{dnsbl}", DEBUG_FULL)
-					rescue Exception
-						debug("unknown error:#{domain}.#{dnsbl}", DEBUG_FULL)
-					end
+			def name_base_black_domain?( domain )
+				@spamlookup_domain_list.split(/[\n\r]+/).inject(false) do |r, dnsbl|
+					r || lookup(domain, dnsbl)
 				end
+			end
 
-				@spamlookup_domain_list.split(/[\n\r]+/).each do |dnsbl|
-					begin
-						timeout(5) do
-							address = Resolv.getaddress( "#{domain}.#{dnsbl}" )
-							debug("lookup:#{domain}.#{dnsbl} address:#{address}")
-							return true
-						end
-					rescue Resolv::ResolvTimeout, Resolv::ResolvError
-					rescue TimeoutError
-						debug("timeout error:#{domain}.#{dnsbl}", DEBUG_FULL)
-					rescue Exception
-						debug("unknown error:#{domain}.#{dnsbl}", DEBUG_FULL)
-					end
+			def ip_base_black_domain?( domain )
+				@spamlookup_ip_list.split(/[\n\r]+/).inject(false) do |r, dnsbl|
+					r || lookup(domain, dnsbl, true)
 				end
+			end
 
-				debug("#{domain} is safe host.", DEBUG_FULL)
+			def lookup(domain, dnsbl, iplookup = false)
+				timeout(5) do
+					domain = IPSocket::getaddress( domain ).split(/\./).reverse.join(".") if iplookup
+					address = Resolv.getaddress( "#{domain}.#{dnsbl}" )
+					debug("lookup:#{domain}.#{dnsbl} address:#{address}: spam host.")
+					return true
+				end
+			rescue TimeoutError, Resolv::ResolvTimeout
+				debug("lookup:#{domain}.#{dnsbl}: safe host.")
+				return false
+			rescue Resolv::ResolvError, Exception
+				debug("unknown error:#{domain}.#{dnsbl}", DEBUG_FULL)
 				return false
 			end
 
@@ -212,7 +185,7 @@ module TDiary
 						debug("#{s[0]} is safe host.", DEBUG_FULL)
 						next
 					end
-					return true if black_domain?( s[0] )
+					return true if name_base_black_domain?( s[0] ) || ip_base_black_domain?( s[0] )
 				end
 				return false
 			end
@@ -262,70 +235,7 @@ module TDiary
 					return @filter_mode
 				end
 
-				if comment.name == 'TrackBack'
-					uri = comment.body.split(/[\r\n]/).first
-					if %r!\A[^:]+://[^/]+/?\z! =~ uri
-						debug( "trackback from top page: #{uri}" )
-						comment.show = false
-						return @filter_mode
-					end
-
-					begin
-						uri = URI.parse(uri)
-						unless /\A(?:https?)\z/i =~ uri.scheme
-							debug( "not http/https: #{uri}" )
-							comment.show = false
-							return @filter_mode
-						end
-					rescue URI::Error
-						debug( "invalid URI: #{uri.dump} (#{$!.message})" )
-						comment.show = false
-						return @filter_mode
-					end
-
-					if @resolv_check
-						chance = 2
-						begin
-							addrs = Resolv.getaddresses(uri.host)
-
-						rescue Resolv::ResolvTimeout, Resolv::ResolvError
-							if chance > 0
-								chance -= 1
-								retry
-							end
-							debug( "resolv error: #{uri.host.dump} (#{$!.message})" )
-							comment.show = false
-							return @resolv_check_mode
-						rescue Exception
-							debug( "unknown resolv error: #{uri.host.dump} (#{$!.message})" )
-							comment.show = false
-							return @resolv_check_mode
-						end
-
-						if addrs.empty?
-							debug( "couldn't get addresses: #{uri.host}" )
-							comment.show = false
-							return @resolv_check_mode
-						end
-
-						unless addrs.include?(@cgi.remote_addr)
-							unless /\A(.*[:.])/ =~ @cgi.remote_addr &&
-									addrs.detect {|a| a.index($1) == 0}
-								debug( "addresses don't match URI: #{uri.host}: #{addrs.join(', ')}" )
-								comment.show = false
-								return @resolv_check_mode
-							end
-						end
-					end
-				end
-
-				if comment.name == 'TrackBack'
-					comment_body = comment.body.sub(/\A[^\r\n]*/, '')
-				else
-					comment_body = comment.body
-				end
-
-				uris = URI.extract( comment_body, %w(http https ftp mailto) )
+				uris = URI.extract( comment.body, %w(http https ftp mailto) )
 				unless uris.empty?
 					if @max_uris && @max_uris >= 0 && uris.size > @max_uris
 						debug( "too many URIs" )
@@ -334,7 +244,7 @@ module TDiary
 					end
 
 					if @max_rate && @max_rate > 0 &&
-							uris.join('').size * 100 / comment_body.gsub(/\s+/, '').size > @max_rate
+							uris.join('').size * 100 / comment.body.gsub(/\s+/, '').size > @max_rate
 						debug( "too many URI-chars" )
 						comment.show = false
 						return @filter_mode
