@@ -3,8 +3,16 @@
 # class IOBase
 #  base of IO class
 #
+require 'fileutils'
+
 module TDiary
 	class BaseIO
+		def initialize( tdiary )
+			@tdiary = tdiary
+			@data_path = @tdiary.conf.data_path if @tdiary.conf.data_path
+			load_styles
+		end
+
 		def calendar
 			raise StandardError, 'not implemented'
 		end
@@ -13,23 +21,29 @@ module TDiary
 			raise StandardError, 'not implemented'
 		end
 
-		def diary_factory(date, title, body, style = nil)
+		def diary_factory(date, title, body, style_name = 'tDiary')
+			style(style_name.downcase).new(date, title, body)
+		end
+
+		def cache_dir
 			raise StandardError, 'not implemented'
 		end
 
-		def styled_diary_factory(date, title, body, style_name = 'tDiary')
-			return style(style_name.downcase).new(date, title, body)
+		def cache_path
+			@_cache_path ||= cache_dir.untaint
+			FileUtils.mkdir_p(@_cache_path)
+			@_cache_path
 		end
 
 		def load_styles
 			@styles = {}
 			paths = @tdiary.conf.options['style.path'] || ["#{TDiary::PATH}/tdiary/style", "#{TDiary::PATH}/tdiary"]
 			[paths].flatten.each do |path|
-				path = path.sub( /\/+$/, '' )
-				Dir::glob( "#{path}/*_style.rb" ) do |style_file|
+				path = path.sub(/\/+$/, '')
+				Dir.glob("#{path}/*_style.rb") do |style_file|
 					require style_file.untaint
-					style = File::basename( style_file ).sub( /_style\.rb$/, '' )
-					@styles[style] = TDiary::const_get( "#{style.capitalize}Diary" )
+					style = File.basename(style_file).sub(/_style\.rb$/, '')
+					@styles[style] = TDiary.const_get("#{style.capitalize}Diary")
 				end
 			end
 		end
@@ -42,7 +56,7 @@ module TDiary
 			unless r
 				raise BadStyleError, "bad style: #{s}"
 			end
-			return r
+			r
 		end
 	end
 end
